@@ -171,11 +171,12 @@ public:
   size_t GetFieldsFree() const;
   size_t GetFieldsSet() const;
 
+  bool IsEmpty() const;
   bool IsValid() const;
 
-  void GetPotential(size_t pos, Bitset& possible, bool incQuad=true);
-  void GetPotential(size_t x, size_t y, Bitset& possible, bool incQuad=true);
-  void GetPotential(size_t x, size_t y, std::vector<size_t>& list, bool incQuad=true);
+  void GetPotential(size_t pos, Bitset& possible, bool incQuad=true) const;
+  void GetPotential(size_t x, size_t y, Bitset& possible, bool incQuad=true) const;
+  void GetPotential(size_t x, size_t y, std::vector<size_t>& list, bool incQuad=true) const;
 
   void SetAreaAsString(const std::wstring& value);
   void GetAreaAsString(std::wstring& value) const;
